@@ -2,6 +2,7 @@ import re
 
 from six import string_types
 
+
 class Action(object):
     """
     Base class for intrinsic function actions. Each intrinsic function must subclass this,
@@ -45,14 +46,15 @@ class Action(object):
         """
 
         return input_dict is not None \
-                   and isinstance(input_dict, dict) \
-                   and len(input_dict) == 1 \
-                   and self.intrinsic_name in input_dict
+            and isinstance(input_dict, dict) \
+            and len(input_dict) == 1 \
+            and self.intrinsic_name in input_dict
 
     @classmethod
     def _parse_resource_reference(cls, ref_value):
         """
-        Splits a resource reference of structure "LogicalId.Property" and returns the "LogicalId" and "Property" separately.
+        Splits a resource reference of structure "LogicalId.Property" and returns the "LogicalId" and "Property"
+        separately.
 
         :param string ref_value: Input reference value which *may* contain the structure "LogicalId.Property"
         :return string, string: Returns two values - logical_id, property. If the input does not contain the structure,
@@ -162,6 +164,7 @@ class RefAction(Action):
             self.intrinsic_name: resolved_value
         }
 
+
 class SubAction(Action):
     intrinsic_name = "Fn::Sub"
 
@@ -189,7 +192,6 @@ class SubAction(Action):
 
         return self._handle_sub_action(input_dict, do_replacement)
 
-
     def resolve_resource_refs(self, input_dict, supported_resource_refs):
         """
         Resolves reference to some property of a resource. Inside string to be substituted, there could be either a
@@ -249,7 +251,6 @@ class SubAction(Action):
 
         return self._handle_sub_action(input_dict, do_replacement)
 
-
     def resolve_resource_id_refs(self, input_dict, supported_resource_id_refs):
         """
         Resolves reference to some property of a resource. Inside string to be substituted, there could be either a
@@ -306,14 +307,13 @@ class SubAction(Action):
 
         return self._handle_sub_action(input_dict, do_replacement)
 
-
     def _handle_sub_action(self, input_dict, handler):
         """
         Handles resolving replacements in the Sub action based on the handler that is passed as an input.
 
         :param input_dict: Dictionary to be resolved
-        :param supported_values: One of several different objects that contain the supported values that need to be changed.
-            See each method above for specifics on these objects.
+        :param supported_values: One of several different objects that contain the supported values that
+            need to be changed. See each method above for specifics on these objects.
         :param handler: handler that is specific to each implementation.
         :return: Resolved value of the Sub dictionary
         """
@@ -327,7 +327,6 @@ class SubAction(Action):
 
         return input_dict
 
-
     def _handle_sub_value(self, sub_value, handler_method):
         """
         Generic method to handle value to Fn::Sub key. We are interested in parsing the ${} syntaxes inside
@@ -365,15 +364,15 @@ class SubAction(Action):
 
         :param string text: Input text
         :param handler_method: Method to be called to handle each occurrence of ${blah} reference structure.
-            First parameter to this method is the full reference structure Ex: ${LogicalId.Property}. Second parameter is just the
-            value of the reference such as "LogicalId.Property"
+            First parameter to this method is the full reference structure Ex: ${LogicalId.Property}.
+            Second parameter is just the value of the reference such as "LogicalId.Property"
 
         :return string: Text with all reference structures replaced as necessary
         """
 
         # RegExp to find pattern "${logicalId.property}" and return the word inside bracket
         logical_id_regex = '[A-Za-z0-9\.]+'
-        ref_pattern = re.compile(r'\$\{('+logical_id_regex+')\}')
+        ref_pattern = re.compile(r'\$\{(' + logical_id_regex + ')\}')
 
         # Find all the pattern, and call the handler to decide how to substitute them.
         # Do the substitution and return the final text
@@ -383,6 +382,7 @@ class SubAction(Action):
                       lambda match: handler_method(match.group(0), match.group(1)),
                       text)
 
+
 class GetAttAction(Action):
     intrinsic_name = "Fn::GetAtt"
 
@@ -390,7 +390,6 @@ class GetAttAction(Action):
         # Parameters can never be referenced within GetAtt value
         return input_dict
 
-
     def resolve_resource_refs(self, input_dict, supported_resource_refs):
         """
         Resolve resource references within a GetAtt dict.
@@ -441,12 +440,11 @@ class GetAttAction(Action):
         splits = value_str.split(self._resource_ref_separator)
         logical_id = splits[0]
         property = splits[1]
-        remaining = splits[2:] # if any
+        remaining = splits[2:]  # if any
 
         resolved_value = supported_resource_refs.get(logical_id, property)
         return self._get_resolved_dictionary(input_dict, key, resolved_value, remaining)
 
-
     def resolve_resource_id_refs(self, input_dict, supported_resource_id_refs):
         """
         Resolve resource references within a GetAtt dict.
@@ -485,12 +483,11 @@ class GetAttAction(Action):
         value_str = self._resource_ref_separator.join(value)
         splits = value_str.split(self._resource_ref_separator)
         logical_id = splits[0]
-        remaining = splits[1:] # if any
+        remaining = splits[1:]  # if any
 
         resolved_value = supported_resource_id_refs.get(logical_id)
         return self._get_resolved_dictionary(input_dict, key, resolved_value, remaining)
 
-
     def _get_resolved_dictionary(self, input_dict, key, resolved_value, remaining):
         """
         Resolves the function and returns the updated dictionary
@@ -505,4 +502,4 @@ class GetAttAction(Action):
             # This is the new value of Fn::GetAtt
             input_dict[key] = [resolved_value] + remaining
 
-        return input_dict
\ No newline at end of file
+        return input_dict
