@@ -1,4 +1,6 @@
 """ CloudFormation Resource serialization, deserialization, and validation """
+from six import string_types
+
 import re
 import inspect
 from samtranslator.model.exceptions import InvalidResourceException
@@ -39,7 +41,7 @@ class Resource(object):
     property_types = None
     _keywords = ['logical_id', 'relative_id', "depends_on", "resource_attributes"]
 
-    _supported_resource_attributes = ["DeletionPolicy", "UpdatePolicy"]
+    _supported_resource_attributes = ["DeletionPolicy", "UpdatePolicy", "Condition"]
 
     # Runtime attributes that can be qureied resource. They are CloudFormation attributes like ARN, Name etc that
     # will be resolvable at runtime. This map will be implemented by sub-classes to express list of attributes they
@@ -94,7 +96,7 @@ class Resource(object):
             translator
         :returns: a Resource object populated from the provided parameters
         :rtype: Resource
-        :raises TypeError: if the provided parmeters are invalid
+        :raises TypeError: if the provided parameters are invalid
         """
 
         resource = cls(logical_id, relative_id=relative_id)
@@ -303,6 +305,18 @@ class Resource(object):
         else:
             raise NotImplementedError(attr_name + " attribute is not implemented for resource " + self.resource_type)
 
+    def get_passthrough_resource_attributes(self):
+        """
+        Returns a dictionary of resource attributes of the ResourceMacro that should be passed through from the main
+        vanilla CloudFormation resource to its children. Currently only Condition is copied.
+
+        :return: Dictionary of resource attributes.
+        """
+        attributes = None
+        if 'Condition' in self.resource_attributes:
+            attributes = {'Condition': self.resource_attributes['Condition']}
+        return attributes
+
 
 class ResourceMacro(Resource):
     """A ResourceMacro object represents a CloudFormation macro. A macro appears in the CloudFormation template in the
@@ -333,6 +347,7 @@ class ResourceMacro(Resource):
         """
         raise NotImplementedError("Method to_cloudformation() must be implemented in a subclass of ResourceMacro")
 
+
 class SamResourceMacro(ResourceMacro):
     """ResourceMacro that specifically refers to SAM (AWS::Serverless::*) resources.
     """
@@ -371,9 +386,10 @@ class SamResourceMacro(ResourceMacro):
         by to_cloudformation() on this SAM resource. Each SAM resource must provide a map of properties that it
         supports and the type of CFN resource this property resolves to.
 
-        :param list of Resource object generated_cfn_resources: List of CloudFormation resources generated by this SAM resource
-        :param samtranslator.intrinsics.resource_refs.SupportedResourceReferences supported_resource_refs: Object holding
-            the mapping between property names and LogicalId of the generated CFN resource it maps to
+        :param list of Resource object generated_cfn_resources: List of CloudFormation resources generated by this
+            SAM resource
+        :param samtranslator.intrinsics.resource_refs.SupportedResourceReferences supported_resource_refs: Object
+            holding the mapping between property names and LogicalId of the generated CFN resource it maps to
         :return: Updated supported_resource_refs
         """
 
@@ -381,7 +397,7 @@ class SamResourceMacro(ResourceMacro):
             raise ValueError("`supported_resource_refs` object is required")
 
         # Create a map of {ResourceType: LogicalId} for quick access
-        resource_id_by_type = {resource.resource_type:resource.logical_id for resource in generated_cfn_resources}
+        resource_id_by_type = {resource.resource_type: resource.logical_id for resource in generated_cfn_resources}
 
         for property, cfn_type in self.referable_properties.items():
             if cfn_type in resource_id_by_type:
@@ -393,7 +409,7 @@ class SamResourceMacro(ResourceMacro):
         if not bool(tags):
             tags = {}
 
-        if additional_tags == None:
+        if additional_tags is None:
             additional_tags = {}
 
         for tag in self._RESERVED_TAGS:
@@ -411,7 +427,19 @@ class SamResourceMacro(ResourceMacro):
         if reserved_tag_name in tags:
             raise InvalidResourceException(self.logical_id, reserved_tag_name + " is a reserved Tag key name and "
                                                                                 "cannot be set on your resource. "
-                                                                                "Please change the tag key in the input.")
+                                                                                "Please change the tag key in the "
+                                                                                "input.")
+
+    def _resolve_string_parameter(self, intrinsics_resolver, parameter_value, parameter_name):
+        if not parameter_value:
+            return parameter_value
+        value = intrinsics_resolver.resolve_parameter_refs(parameter_value)
+
+        if not isinstance(value, string_types) and not isinstance(value, dict):
+            raise InvalidResourceException(self.logical_id,
+                                           "Could not resolve parameter for '{}' or parameter is not a String."
+                                           .format(parameter_name))
+        return value
 
 
 class ResourceTypeResolver(object):
@@ -427,9 +455,9 @@ class ResourceTypeResolver(object):
         for module in modules:
             # Get all classes in the specified module which have a class variable resource_type.
             for _, resource_class in inspect.getmembers(module,
-                                                        lambda cls: inspect.isclass(cls)
-                                                        and cls.__module__ == module.__name__
-                                                        and hasattr(cls, 'resource_type')):
+                                                        lambda cls: inspect.isclass(cls) and
+                                                        cls.__module__ == module.__name__ and
+                                                        hasattr(cls, 'resource_type')):
                 self.resource_types[resource_class.resource_type] = resource_class
 
     def can_resolve(self, resource_dict):
@@ -446,8 +474,8 @@ class ResourceTypeResolver(object):
         :rtype: class
         """
         if not self.can_resolve(resource_dict):
-            raise TypeError("Resource dict has missing or invalid value for key Type. Resource Dict is: "
-                            + str(resource_dict))
+            raise TypeError("Resource dict has missing or invalid value for key Type. Resource Dict is: " +
+                            str(resource_dict))
         if resource_dict['Type'] not in self.resource_types:
             raise TypeError("Invalid resource type {resource_type}".format(resource_type=resource_dict['Type']))
         return self.resource_types[resource_dict['Type']]
