@@ -1,6 +1,6 @@
 from samtranslator.model import PropertyType, Resource
-from samtranslator.model.types import is_type, one_of, is_str, list_of, any_type
-from samtranslator.model.intrinsics import fnGetAtt, ref
+from samtranslator.model.types import is_type, is_str, list_of
+from samtranslator.model.intrinsics import ref
 
 
 class NestedStack(Resource):
@@ -16,4 +16,4 @@ class NestedStack(Resource):
 
     runtime_attrs = {
         "stack_id": lambda self: ref(self.logical_id)
-    }
\ No newline at end of file
+    }
