@@ -1,19 +1,23 @@
 import copy
+import re
 from six import string_types
 from samtranslator.model import ResourceMacro, PropertyType
 from samtranslator.model.types import is_type, list_of, dict_of, one_of, is_str
-from samtranslator.model.intrinsics import ref, fnSub, make_shorthand
+from samtranslator.model.intrinsics import ref, fnSub, make_shorthand, make_conditional
+from samtranslator.model.tags.resource_tagging import get_tag_list
 
 from samtranslator.model.s3 import S3Bucket
 from samtranslator.model.sns import SNSSubscription
 from samtranslator.model.lambda_ import LambdaPermission
 from samtranslator.model.events import EventsRule
-from samtranslator.model.log import SubscriptionFilter
 from samtranslator.model.iot import IotTopicRule
 from samtranslator.translator.arn_generator import ArnGenerator
 from samtranslator.model.exceptions import InvalidEventException
 from samtranslator.swagger.swagger import SwaggerEditor
 
+CONDITION = 'Condition'
+
+
 class PushEventSource(ResourceMacro):
     """Base class for push event sources for SAM Functions.
 
@@ -43,7 +47,8 @@ class PushEventSource(ResourceMacro):
         :returns: the permission resource
         :rtype: model.lambda_.LambdaPermission
         """
-        lambda_permission = LambdaPermission(self.logical_id + 'Permission' + suffix)
+        lambda_permission = LambdaPermission(self.logical_id + 'Permission' + suffix,
+                                             attributes=function.get_passthrough_resource_attributes())
 
         try:
             # Name will not be available for Alias resources
@@ -91,7 +96,8 @@ class Schedule(PushEventSource):
         events_rule.Targets = [self._construct_target(function)]
 
         source_arn = events_rule.get_runtime_attr("arn")
-
+        if CONDITION in function.resource_attributes:
+            events_rule.set_resource_attribute(CONDITION, function.resource_attributes[CONDITION])
         resources.append(self._construct_permission(function, source_arn=source_arn))
 
         return resources
@@ -104,7 +110,7 @@ class Schedule(PushEventSource):
         """
         target = {
                 'Arn': function.get_runtime_attr("arn"),
-                'Id':  self.logical_id + 'LambdaTarget'
+                'Id': self.logical_id + 'LambdaTarget'
         }
         if self.Input is not None:
             target['Input'] = self.Input
@@ -138,12 +144,14 @@ class CloudWatchEvent(PushEventSource):
         resources = []
 
         events_rule = EventsRule(self.logical_id)
-        resources.append(events_rule)
-
         events_rule.EventPattern = self.Pattern
         events_rule.Targets = [self._construct_target(function)]
-        source_arn = events_rule.get_runtime_attr("arn")
+        if CONDITION in function.resource_attributes:
+            events_rule.set_resource_attribute(CONDITION, function.resource_attributes[CONDITION])
 
+        resources.append(events_rule)
+
+        source_arn = events_rule.get_runtime_attr("arn")
         resources.append(self._construct_permission(function, source_arn=source_arn))
 
         return resources
@@ -156,7 +164,7 @@ class CloudWatchEvent(PushEventSource):
         """
         target = {
                 'Arn': function.get_runtime_attr("arn"),
-                'Id':  self.logical_id + 'LambdaTarget'
+                'Id': self.logical_id + 'LambdaTarget'
         }
         if self.Input is not None:
             target['Input'] = self.Input
@@ -165,6 +173,7 @@ class CloudWatchEvent(PushEventSource):
             target['InputPath'] = self.InputPath
         return target
 
+
 class S3(PushEventSource):
     """S3 bucket event source for SAM Functions."""
     resource_type = 'S3'
@@ -210,7 +219,10 @@ class S3(PushEventSource):
 
         source_account = ref('AWS::AccountId')
         permission = self._construct_permission(function, source_account=source_account)
-        self._depend_on_lambda_permissions(bucket, permission)
+        if CONDITION in permission.resource_attributes:
+            self._depend_on_lambda_permissions_using_tag(bucket, permission)
+        else:
+            self._depend_on_lambda_permissions(bucket, permission)
         resources.append(permission)
 
         # NOTE: `bucket` here is a dictionary representing the S3 Bucket resource in your SAM template. If there are
@@ -245,7 +257,7 @@ class S3(PushEventSource):
 
         # DependsOn can be either a list of strings or a scalar string
         if isinstance(depends_on, string_types):
-            depends_on = [ depends_on ]
+            depends_on = [depends_on]
 
         depends_on_set = set(depends_on)
         depends_on_set.add(permission.logical_id)
@@ -253,6 +265,37 @@ class S3(PushEventSource):
 
         return bucket
 
+    def _depend_on_lambda_permissions_using_tag(self, bucket, permission):
+        """
+        Since conditional DependsOn is not supported this undocumented way of
+        implicitely  making dependency through tags is used.
+
+        See https://stackoverflow.com/questions/34607476/cloudformation-apply-condition-on-dependson
+
+        It is done by using Ref wrapped in a conditional Fn::If. Using Ref implies a
+        dependency, so CloudFormation will automatically wait once it reaches that function, the same
+        as if you were using a DependsOn.
+        """
+        properties = bucket.get('Properties', None)
+        if properties is None:
+            properties = {}
+            bucket['Properties'] = properties
+        tags = properties.get('Tags', None)
+        if tags is None:
+            tags = []
+            properties['Tags'] = tags
+        dep_tag = {
+            'sam:ConditionalDependsOn:' + permission.logical_id: {
+                'Fn::If': [
+                    permission.resource_attributes[CONDITION],
+                    ref(permission.logical_id),
+                    'no dependency'
+                ]
+            }
+        }
+        properties['Tags'] = tags + get_tag_list(dep_tag)
+        return bucket
+
     def _inject_notification_configuration(self, function, bucket):
         base_event_mapping = {
             'Function': function.get_runtime_attr("arn")
@@ -270,7 +313,8 @@ class S3(PushEventSource):
 
             lambda_event = copy.deepcopy(base_event_mapping)
             lambda_event['Event'] = event_type
-
+            if CONDITION in function.resource_attributes:
+                lambda_event = make_conditional(function.resource_attributes[CONDITION], lambda_event)
             event_mappings.append(lambda_event)
 
         properties = bucket.get('Properties', None)
@@ -299,7 +343,8 @@ class SNS(PushEventSource):
     resource_type = 'SNS'
     principal = 'sns.amazonaws.com'
     property_types = {
-            'Topic': PropertyType(True, is_str())
+            'Topic': PropertyType(True, is_str()),
+            'FilterPolicy': PropertyType(False, dict_of(is_str(), list_of(one_of(is_str(), is_type(dict)))))
     }
 
     def to_cloudformation(self, **kwargs):
@@ -315,13 +360,18 @@ class SNS(PushEventSource):
             raise TypeError("Missing required keyword argument: function")
 
         return [self._construct_permission(function, source_arn=self.Topic),
-                self._inject_subscription(function, self.Topic)]
+                self._inject_subscription(function, self.Topic, self.FilterPolicy)]
 
-    def _inject_subscription(self, function, topic):
+    def _inject_subscription(self, function, topic, filterPolicy):
         subscription = SNSSubscription(self.logical_id)
         subscription.Protocol = 'lambda'
         subscription.Endpoint = function.get_runtime_attr("arn")
         subscription.TopicArn = topic
+        if CONDITION in function.resource_attributes:
+            subscription.set_resource_attribute(CONDITION, function.resource_attributes[CONDITION])
+
+        if filterPolicy is not None:
+            subscription.FilterPolicy = filterPolicy
 
         return subscription
 
@@ -431,11 +481,15 @@ class Api(PushEventSource):
         return permissions
 
     def _get_permission(self, resources_to_link, stage, suffix):
+        # It turns out that APIGW doesn't like trailing slashes in paths (#665)
+        # and removes as a part of their behaviour, but this isn't documented.
+        # The regex removes the tailing slash to ensure the permission works as intended
+        path = re.sub(r'^(.+)/$', r'\1', self.Path)
 
         if not stage or not suffix:
             raise RuntimeError("Could not add permission to lambda function.")
 
-        path = self.Path.replace('{proxy+}', '*')
+        path = path.replace('{proxy+}', '*')
         method = '*' if self.Method.lower() == 'any' else self.Method.upper()
 
         api_id = self.RestApiId
@@ -459,8 +513,8 @@ class Api(PushEventSource):
 
         function_arn = function.get_runtime_attr('arn')
         partition = ArnGenerator.get_partition_name()
-        uri = fnSub('arn:'+partition+':apigateway:${AWS::Region}:lambda:path/2015-03-31/functions/'
-                    + make_shorthand(function_arn) + '/invocations')
+        uri = fnSub('arn:' + partition + ':apigateway:${AWS::Region}:lambda:path/2015-03-31/functions/' +
+                    make_shorthand(function_arn) + '/invocations')
 
         editor = SwaggerEditor(swagger_body)
 
@@ -471,7 +525,11 @@ class Api(PushEventSource):
                 'API method "{method}" defined multiple times for path "{path}".'.format(
                     method=self.Method, path=self.Path))
 
-        editor.add_lambda_integration(self.Path, self.Method, uri)
+        condition = None
+        if CONDITION in function.resource_attributes:
+            condition = function.resource_attributes[CONDITION]
+
+        editor.add_lambda_integration(self.Path, self.Method, uri, condition=condition)
 
         if self.Auth:
             method_authorizer = self.Auth.get('Authorizer')
@@ -575,5 +633,7 @@ class IoTRule(PushEventSource):
             payload['AwsIotSqlVersion'] = self.AwsIotSqlVersion
 
         rule.TopicRulePayload = payload
+        if CONDITION in function.resource_attributes:
+            rule.set_resource_attribute(CONDITION, function.resource_attributes[CONDITION])
 
         return rule
