@@ -1,5 +1,5 @@
 from samtranslator.model import PropertyType, Resource
-from samtranslator.model.types import is_str
+from samtranslator.model.types import is_type, is_str
 
 
 class SNSSubscription(Resource):
@@ -7,5 +7,6 @@ class SNSSubscription(Resource):
     property_types = {
         'Endpoint': PropertyType(True, is_str()),
         'Protocol': PropertyType(True, is_str()),
-        'TopicArn': PropertyType(True, is_str())
+        'TopicArn': PropertyType(True, is_str()),
+        'FilterPolicy': PropertyType(False, is_type(dict))
     }
